==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/OVNKubernetesConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OVNKubernetesConfigBuilder extends io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig,io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigBuilder>{
  public OVNKubernetesConfigBuilder() {
    this(false);
  }
  public OVNKubernetesConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new OVNKubernetesConfig(), validationEnabled);
  }
  public OVNKubernetesConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public OVNKubernetesConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OVNKubernetesConfig(), validationEnabled);
  }
  public OVNKubernetesConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig instance) {
    this(fluent, instance, false);
  }
  public OVNKubernetesConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGenevePort(instance.getGenevePort()); 
    fluent.withHybridOverlayConfig(instance.getHybridOverlayConfig()); 
    fluent.withIpsecConfig(instance.getIpsecConfig()); 
    fluent.withMtu(instance.getMtu()); 
    fluent.withPolicyAuditConfig(instance.getPolicyAuditConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OVNKubernetesConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig instance) {
    this(instance,false);
  }
  public OVNKubernetesConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGenevePort(instance.getGenevePort()); 
    this.withHybridOverlayConfig(instance.getHybridOverlayConfig()); 
    this.withIpsecConfig(instance.getIpsecConfig()); 
    this.withMtu(instance.getMtu()); 
    this.withPolicyAuditConfig(instance.getPolicyAuditConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OVNKubernetesConfig build() {
    OVNKubernetesConfig buildable = new OVNKubernetesConfig(fluent.getGenevePort(),fluent.getHybridOverlayConfig(),fluent.getIpsecConfig(),fluent.getMtu(),fluent.getPolicyAuditConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OVNKubernetesConfigBuilder that = (OVNKubernetesConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OVNKubernetesConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OVNKubernetesConfigBuilder extends OVNKubernetesConfigFluentImpl<OVNKubernetesConfigBuilder> implements VisitableBuilder<OVNKubernetesConfig,OVNKubernetesConfigBuilder>{
  public OVNKubernetesConfigBuilder() {
    this(false);
  }
  public OVNKubernetesConfigBuilder(Boolean validationEnabled) {
    this(new OVNKubernetesConfig(), validationEnabled);
  }
  public OVNKubernetesConfigBuilder(OVNKubernetesConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public OVNKubernetesConfigBuilder(OVNKubernetesConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OVNKubernetesConfig(), validationEnabled);
  }
  public OVNKubernetesConfigBuilder(OVNKubernetesConfigFluent<?> fluent,OVNKubernetesConfig instance) {
    this(fluent, instance, false);
  }
  public OVNKubernetesConfigBuilder(OVNKubernetesConfigFluent<?> fluent,OVNKubernetesConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGenevePort(instance.getGenevePort()); 
    fluent.withHybridOverlayConfig(instance.getHybridOverlayConfig()); 
    fluent.withIpsecConfig(instance.getIpsecConfig()); 
    fluent.withMtu(instance.getMtu()); 
    fluent.withPolicyAuditConfig(instance.getPolicyAuditConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OVNKubernetesConfigBuilder(OVNKubernetesConfig instance) {
    this(instance,false);
  }
  public OVNKubernetesConfigBuilder(OVNKubernetesConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withGenevePort(instance.getGenevePort()); 
    this.withHybridOverlayConfig(instance.getHybridOverlayConfig()); 
    this.withIpsecConfig(instance.getIpsecConfig()); 
    this.withMtu(instance.getMtu()); 
    this.withPolicyAuditConfig(instance.getPolicyAuditConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  OVNKubernetesConfigFluent<?> fluent;
  Boolean validationEnabled;
  public OVNKubernetesConfig build() {
    OVNKubernetesConfig buildable = new OVNKubernetesConfig(fluent.getGenevePort(),fluent.getHybridOverlayConfig(),fluent.getIpsecConfig(),fluent.getMtu(),fluent.getPolicyAuditConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
